'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');

const defaultContextValue = {
    activeCategory: "smilieys",
    toggleActiveCategory: () => { },
};
const ActiveCategoryContext = react.createContext(defaultContextValue);

const emojiCategories = [
    {
        name: 'smilieys',
        label: 'スマイリー',
    },
    {
        name: 'people',
        label: '人々',
    },
    {
        name: 'animals-and-nature',
        label: '動物と自然',
    },
    {
        name: 'food',
        label: '食べ物',
    },
    {
        name: 'activity',
        label: '活動',
    },
    {
        name: 'travel-and-place',
        label: '旅行と場所',
    },
    {
        name: 'objects',
        label: '物',
    },
    {
        name: 'symbols',
        label: 'シンボル',
    },
];
const categoryNames = [
    'smilieys',
    'people',
    'animals-and-nature',
    'food',
    'activity',
    'travel-and-place',
    'objects',
    'symbols',
];

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z$6 = ".Skeleton-module_skeleton__TVCzE {\n  width: 30px;\n  height: 30px;\n  background-color: #e2dcdc;\n  border-radius: 8px;\n  animation: Skeleton-module_pulse__oDmiQ 1.5s ease-in-out infinite; /* パルスアニメーション */\n}\n\n@keyframes Skeleton-module_pulse__oDmiQ {\n  0%,\n  100% {\n    opacity: 1;\n  }\n  50% {\n    opacity: 0.5;\n  }\n}\n";
var styles$5 = {"skeleton":"Skeleton-module_skeleton__TVCzE","pulse":"Skeleton-module_pulse__oDmiQ"};
styleInject(css_248z$6);

const Skeleton = () => {
    return jsxRuntime.jsx("div", { className: styles$5.skeleton });
};

var css_248z$5 = ".ThreeDotsLoading-module_ldsGrid__RMhYe {\n  display: block;\n  position: relative;\n  width: 70px;\n  height: 30px;\n  margin-right: 0.25rem;\n  margin-top: 1rem;\n  margin-bottom: 1rem;\n  justify-self: center;\n}\n\n.ThreeDotsLoading-module_ldsGridDiv__7o8SU {\n  position: absolute;\n  width: 14px;\n  height: 14px;\n  border-radius: 50%;\n  background: #e2dcdc;\n  animation: ThreeDotsLoading-module_ldsGridAnimation__xiDWG 1.2s linear infinite;\n}\n\n.ThreeDotsLoading-module_ldsGridDiv1__-NzHM {\n  top: 8px;\n  left: 8px;\n  animation-delay: 0s;\n}\n\n.ThreeDotsLoading-module_ldsGridDiv2__IPFfK {\n  top: 8px;\n  left: 32px;\n  animation-delay: -0.4s;\n}\n\n.ThreeDotsLoading-module_ldsGridDiv3__DW513 {\n  top: 8px;\n  left: 56px;\n  animation-delay: -0.8s;\n}\n\n@keyframes ThreeDotsLoading-module_ldsGridAnimation__xiDWG {\n  0%,\n  100% {\n    opacity: 1;\n  }\n  50% {\n    opacity: 0.5;\n  }\n}\n";
styleInject(css_248z$5);

const defaultHandleEmojiClickContextValue = {
    handleEmojiSelect: () => { },
};
const HandleEmojiClickContext = react.createContext(defaultHandleEmojiClickContextValue);

const useHandleEmojiClick = () => {
    return react.useContext(HandleEmojiClickContext);
};

var css_248z$4 = ".Category-module_section__1hMGw {\n  display: grid;\n  grid-gap: 0.25rem;\n  padding-right: 1rem;\n}\n\n.Category-module_heading__LzY0I {\n  color: #6b7280;\n  font-size: 0.875rem;\n  font-weight: 600;\n  padding-left: 0.25rem;\n  padding-top: 0.5rem;\n  padding-bottom: 0.375rem;\n  position: sticky;\n  top: 0;\n  z-index: 1;\n  background-color: rgba(255, 255, 255, 0.8);\n  -webkit-backdrop-filter: blur(5px);\n          backdrop-filter: blur(5px);\n  transition: color 0.3s;\n}\n\n.Category-module_gridContainer__cBGFN {\n  display: grid;\n  grid-template-columns: repeat(8, minmax(0, 1fr));\n}\n\n.Category-module_button__7cUf1 {\n  padding: 0.125rem;\n  border-radius: 0.375rem;\n  transition: background-color 0.3s;\n}\n\n.Category-module_button__7cUf1:hover {\n  background-color: #bfdbfe;\n}\n\n.Category-module_image__rTtEr {\n  width: 30px;\n  height: 30px;\n}\n";
var styles$4 = {"section":"Category-module_section__1hMGw","heading":"Category-module_heading__LzY0I","gridContainer":"Category-module_gridContainer__cBGFN","button":"Category-module_button__7cUf1","image":"Category-module_image__rTtEr"};
styleInject(css_248z$4);

const useActiveCategory = () => {
    return react.useContext(ActiveCategoryContext);
};

const fetchEmojiList = async (category) => {
    const res = await fetch(`https://ms-emoji.yajihum.dev/?category=${category.name}`);
    return await res.json();
};

const useEmojiList = ({ category }) => {
    const [imageNames, setImageNames] = react.useState([]);
    react.useEffect(() => {
        const getData = async () => {
            console.log("category", category);
            return await fetchEmojiList(category);
        };
        getData().then((data) => setImageNames(data));
    }, [category]);
    const emojiListByCategory = imageNames.map((image) => {
        const [name, extension] = image.split(".");
        return {
            url: `https://cdn.emoji.yajihum.dev/${category.name}/${name}.${extension}`,
            name,
            extension,
            category: category.name,
        };
    });
    const sortedEmojiListByCategory = emojiListByCategory
        .slice()
        .sort((a, b) => Number(a.name) - Number(b.name));
    return {
        ...category,
        emojiImages: sortedEmojiListByCategory,
    };
};

const EmojiListByCategory = ({ category }) => {
    const { emojiImages } = useEmojiList({ category });
    const { handleEmojiSelect } = useHandleEmojiClick();
    const [loadedStates, setLoadedStates] = react.useState({});
    const handleLoad = (name) => {
        setLoadedStates((prev) => ({ ...prev, [name]: true }));
    };
    return (jsxRuntime.jsx("div", { className: styles$4.gridContainer, children: emojiImages.map((emoji) => (jsxRuntime.jsxs("button", { type: "button", onClick: () => handleEmojiSelect(emoji), className: styles$4.button, children: [!loadedStates[emoji.name] && jsxRuntime.jsx(Skeleton, {}), jsxRuntime.jsx("img", { src: emoji.url, className: styles$4.image, alt: `${emoji.category} | ${emoji.name}`, onLoad: () => handleLoad(emoji.name), style: { display: loadedStates[emoji.name] ? "block" : "none" } })] }, emoji.name))) }));
};
const formatString = (str) => {
    const capitalizedFirst = str.charAt(0).toUpperCase() + str.slice(1);
    return capitalizedFirst.replace(/-/g, " ");
};
const CategorySection = react.forwardRef(({ category }, ref) => {
    const { activeCategory, toggleActiveCategory } = useActiveCategory();
    const categoryRefs = react.useRef({});
    const rootElement = typeof ref === "object" && ref && ref.current ? ref.current : null;
    react.useEffect(() => {
        const observer = new IntersectionObserver((entries) => {
            for (const entry of entries) {
                if (entry.isIntersecting &&
                    entry.intersectionRatio > 0 &&
                    entry.target.id) {
                    toggleActiveCategory(entry.target.id);
                }
            }
        }, {
            root: rootElement,
            rootMargin: "0px 0px -100px 0px",
        });
        for (const ref of Object.values(categoryRefs.current)) {
            if (ref)
                observer.observe(ref);
        }
        return () => {
            for (const ref of Object.values(categoryRefs.current)) {
                if (ref)
                    observer.unobserve(ref);
            }
        };
    }, [toggleActiveCategory, rootElement]);
    return (jsxRuntime.jsxs("section", { id: category.name, className: styles$4.section, children: [jsxRuntime.jsx("h2", { id: category.name, ref: (el) => {
                    categoryRefs.current[category.label] = el;
                }, className: styles$4.heading, children: formatString(category.name) }), jsxRuntime.jsx(EmojiListByCategory, { category: category })] }, category.name));
});

var css_248z$3 = ".EmojiSection-module_section__zudh- {\n  padding-left: 1rem; /* pl-4 */\n  padding-bottom: 1rem; /* pb-4 */\n}\n\n.EmojiSection-module_container__kf-e8 {\n  display: grid;\n  grid-row-gap: 0.75rem; /* gap-3 */\n  overflow: auto;\n  height: 24rem; /* h-96 */\n  scrollbar-color: #eaeaea #ffffff; /* Firefox用のスクロールバーの色 */\n  scrollbar-width: thin; /* Firefox用のスクロールバーの幅 */\n}\n\n/* Webkitブラウザ用のスクロールバーのスタイル */\n.container::-webkit-scrollbar {\n  width: 20px;\n}\n\n.container::-webkit-scrollbar-track {\n  background: #ffffff;\n}\n\n.container::-webkit-scrollbar-thumb {\n  background: #eaeaea;\n  border-radius: 100vh;\n  border: 5px solid #ffffff;\n  height: 80px;\n}\n";
var styles$3 = {"section":"EmojiSection-module_section__zudh-","container":"EmojiSection-module_container__kf-e8"};
styleInject(css_248z$3);

const EmojiSection = () => {
    const containerRef = react.useRef(null);
    return (jsxRuntime.jsx("section", { className: styles$3.section, children: jsxRuntime.jsx("div", { ref: containerRef, className: styles$3.container, children: emojiCategories.map((category) => (jsxRuntime.jsx(CategorySection, { category: category }, category.name))) }) }));
};

var css_248z$2 = ".Button-module_button__c6nkW {\n  padding: 0.25rem; /* p-1 */\n}\n";
var styles$2 = {"button":"Button-module_button__c6nkW"};
styleInject(css_248z$2);

const Button = react.forwardRef(function ButtonBase({ className, children, ...props }, ref) {
    const buttonClass = className
        ? `${styles$2.button} ${className}`
        : styles$2.button;
    return (jsxRuntime.jsx("button", { ...props, ref: ref, className: buttonClass, children: children }));
});

const SmileyFaceIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M12 12m-9 0a9 9 0 1 0 18 0a9 9 0 1 0 -18 0" }), jsxRuntime.jsx("path", { d: "M9 10l.01 0" }), jsxRuntime.jsx("path", { d: "M15 10l.01 0" }), jsxRuntime.jsx("path", { d: "M9.5 15a3.5 3.5 0 0 0 5 0" })] }));
const PeopleIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M9 7m-4 0a4 4 0 1 0 8 0a4 4 0 1 0 -8 0" }), jsxRuntime.jsx("path", { d: "M3 21v-2a4 4 0 0 1 4 -4h4a4 4 0 0 1 4 4v2" }), jsxRuntime.jsx("path", { d: "M16 3.13a4 4 0 0 1 0 7.75" }), jsxRuntime.jsx("path", { d: "M21 21v-2a4 4 0 0 0 -3 -3.85" })] }));
const DogIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M14.7 13.5c-1.1 -2 -1.441 -2.5 -2.7 -2.5c-1.259 0 -1.736 .755 -2.836 2.747c-.942 1.703 -2.846 1.845 -3.321 3.291c-.097 .265 -.145 .677 -.143 .962c0 1.176 .787 2 1.8 2c1.259 0 3 -1 4.5 -1s3.241 1 4.5 1c1.013 0 1.8 -.823 1.8 -2c0 -.285 -.049 -.697 -.146 -.962c-.475 -1.451 -2.512 -1.835 -3.454 -3.538z" }), jsxRuntime.jsx("path", { d: "M20.188 8.082a1.039 1.039 0 0 0 -.406 -.082h-.015c-.735 .012 -1.56 .75 -1.993 1.866c-.519 1.335 -.28 2.7 .538 3.052c.129 .055 .267 .082 .406 .082c.739 0 1.575 -.742 2.011 -1.866c.516 -1.335 .273 -2.7 -.54 -3.052z" }), jsxRuntime.jsx("path", { d: "M9.474 9c.055 0 .109 0 .163 -.011c.944 -.128 1.533 -1.346 1.32 -2.722c-.203 -1.297 -1.047 -2.267 -1.932 -2.267c-.055 0 -.109 0 -.163 .011c-.944 .128 -1.533 1.346 -1.32 2.722c.204 1.293 1.048 2.267 1.933 2.267z" }), jsxRuntime.jsx("path", { d: "M16.456 6.733c.214 -1.376 -.375 -2.594 -1.32 -2.722a1.164 1.164 0 0 0 -.162 -.011c-.885 0 -1.728 .97 -1.93 2.267c-.214 1.376 .375 2.594 1.32 2.722c.054 .007 .108 .011 .162 .011c.885 0 1.73 -.974 1.93 -2.267z" }), jsxRuntime.jsx("path", { d: "M5.69 12.918c.816 -.352 1.054 -1.719 .536 -3.052c-.436 -1.124 -1.271 -1.866 -2.009 -1.866c-.14 0 -.277 .027 -.407 .082c-.816 .352 -1.054 1.719 -.536 3.052c.436 1.124 1.271 1.866 2.009 1.866c.14 0 .277 -.027 .407 -.082z" })] }));
const AppleIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M12 14m-7 0a7 7 0 1 0 14 0a7 7 0 1 0 -14 0" }), jsxRuntime.jsx("path", { d: "M12 11v-6a2 2 0 0 1 2 -2h2v1a2 2 0 0 1 -2 2h-2" }), jsxRuntime.jsx("path", { d: "M10 10.5c1.333 .667 2.667 .667 4 0" })] }));
const BallIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M12 12m-9 0a9 9 0 1 0 18 0a9 9 0 1 0 -18 0" }), jsxRuntime.jsx("path", { d: "M6 5.3a9 9 0 0 1 0 13.4" }), jsxRuntime.jsx("path", { d: "M18 5.3a9 9 0 0 0 0 13.4" })] }));
const PlanetIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M18.816 13.58c2.292 2.138 3.546 4 3.092 4.9c-.745 1.46 -5.783 -.259 -11.255 -3.838c-5.47 -3.579 -9.304 -7.664 -8.56 -9.123c.464 -.91 2.926 -.444 5.803 .805" }), jsxRuntime.jsx("path", { d: "M12 12m-7 0a7 7 0 1 0 14 0a7 7 0 1 0 -14 0" })] }));
const LightBulbIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M3 12h1m8 -9v1m8 8h1m-15.4 -6.4l.7 .7m12.1 -.7l-.7 .7" }), jsxRuntime.jsx("path", { d: "M9 16a5 5 0 1 1 6 0a3.5 3.5 0 0 0 -1 3a2 2 0 0 1 -4 0a3.5 3.5 0 0 0 -1 -3" }), jsxRuntime.jsx("path", { d: "M9.7 17l4.6 0" })] }));
const SymbolIcon = () => (jsxRuntime.jsxs("svg", { xmlns: "http://www.w3.org/2000/svg", width: "24", height: "24", viewBox: "0 0 24 24", strokeWidth: "2", stroke: "currentColor", fill: "none", strokeLinecap: "round", strokeLinejoin: "round", children: [jsxRuntime.jsx("path", { stroke: "none", d: "M0 0h24v24H0z", fill: "none" }), jsxRuntime.jsx("path", { d: "M3 10l2 -2v8" }), jsxRuntime.jsx("path", { d: "M9 8h3a1 1 0 0 1 1 1v2a1 1 0 0 1 -1 1h-2a1 1 0 0 0 -1 1v2a1 1 0 0 0 1 1h3" }), jsxRuntime.jsx("path", { d: "M17 8h2.5a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1 -1.5 1.5h-1.5h1.5a1.5 1.5 0 0 1 1.5 1.5v1a1.5 1.5 0 0 1 -1.5 1.5h-2.5" })] }));

var css_248z$1 = ".NavigationSection-module_navigation__0HDY2 {\n  border-bottom: 2px solid #f3f4f6; /* border-gray-100 */\n}\n\n.NavigationSection-module_gridContainer__EPsiC {\n  display: grid;\n  grid-template-columns: repeat(8, minmax(0, 1fr));\n  justify-items: center;\n  padding-right: 1.25rem; /* pr-5 */\n  padding-left: 0.75rem; /* pl-3 */\n  padding-top: 0.75rem; /* py-3 */\n  padding-bottom: 0.75rem; /* py-3 */\n}\n\n.NavigationSection-module_button__f-Co5 {\n  width: 1.75rem; /* w-7 */\n  height: 1.75rem; /* h-7 */\n  fill: currentColor;\n}\n\n.NavigationSection-module_activeButton__zV83d {\n  color: #2563eb; /* text-blue-600 */\n  text-decoration: underline;\n  text-underline-offset: 2px;\n}\n\n.NavigationSection-module_inactiveButton__hdJ0r {\n  color: #9ca3af; /* text-gray-400 */\n}\n";
var styles$1 = {"navigation":"NavigationSection-module_navigation__0HDY2","gridContainer":"NavigationSection-module_gridContainer__EPsiC","button":"NavigationSection-module_button__f-Co5","activeButton":"NavigationSection-module_activeButton__zV83d","inactiveButton":"NavigationSection-module_inactiveButton__hdJ0r"};
styleInject(css_248z$1);

const iconComponents = {
    smilieys: jsxRuntime.jsx(SmileyFaceIcon, {}, "smilieys"),
    people: jsxRuntime.jsx(PeopleIcon, {}, "people"),
    "animals-and-nature": jsxRuntime.jsx(DogIcon, {}, "animalsAndNatureog"),
    food: jsxRuntime.jsx(AppleIcon, {}, "food"),
    activity: jsxRuntime.jsx(BallIcon, {}, "activity"),
    "travel-and-place": jsxRuntime.jsx(PlanetIcon, {}, "travelAndPlace"),
    objects: jsxRuntime.jsx(LightBulbIcon, {}, "objects"),
    symbols: jsxRuntime.jsx(SymbolIcon, {}, "symbols"),
};
const initisalNavIcons = categoryNames.map((name, index) => {
    return {
        name: name,
        element: iconComponents[name],
        isActive: index === 0,
    };
});
const getNewNavIcons = (navIcons, activeCategory) => {
    return navIcons.map((icon) => {
        if (icon.name === activeCategory) {
            return {
                ...icon,
                isActive: true,
            };
        }
        return {
            ...icon,
            isActive: false,
        };
    });
};
const handleButtonClick = (categoryName) => {
    const sectionElement = document.getElementById(categoryName);
    if (sectionElement) {
        sectionElement.scrollIntoView({ behavior: "instant" }); // スムーズスクロール
    }
};
const NavigationSection = () => {
    const { activeCategory } = useActiveCategory();
    console.log("activeCategory", activeCategory);
    const [navIcons, setNavIcons] = react.useState(initisalNavIcons);
    react.useEffect(() => {
        setNavIcons((prevNavIcons) => getNewNavIcons(prevNavIcons, activeCategory));
    }, [activeCategory]);
    return (jsxRuntime.jsx("nav", { className: styles$1.navigation, children: jsxRuntime.jsx("div", { className: styles$1.gridContainer, children: navIcons.map((icon) => (jsxRuntime.jsx(Button, { type: "button", onClick: () => {
                    setNavIcons((prev) => getNewNavIcons(prev, icon.name));
                    handleButtonClick(icon.name);
                }, className: `${styles$1.button} ${icon.isActive ? styles$1.activeButton : styles$1.inactiveButton}`, children: icon.element }, icon.element.key))) }) }));
};

var css_248z = ".Picker-module_pickerContainer__02iFK {\n  box-shadow: 0 10px 15px -3px rgba(0, 0, 0, 0.1),\n    0 4px 6px -2px rgba(0, 0, 0, 0.05);\n  border-radius: 1rem;\n  background-color: #ffffff;\n  width: 20rem;\n}\n\n.Picker-module_hidden__YncP3 {\n  display: none;\n}\n\n.Picker-module_block__9xMhy {\n  display: block;\n}\n";
var styles = {"pickerContainer":"Picker-module_pickerContainer__02iFK","hidden":"Picker-module_hidden__YncP3","block":"Picker-module_block__9xMhy"};
styleInject(css_248z);

const Picker = ({ isOpen = false, handleEmojiSelect = () => { }, }) => {
    const [activeCategory, setActiveCategory] = react.useState('smilieys');
    const toggleActiveCategory = (category) => {
        setActiveCategory(category);
    };
    react.useEffect(() => {
        if (isOpen) {
            setActiveCategory('smileys');
        }
    }, [isOpen]);
    if (!isOpen)
        return null;
    return (jsxRuntime.jsx("section", { "aria-label": "Picker", className: styles.pickerContainer, children: jsxRuntime.jsx(ActiveCategoryContext.Provider, { value: { activeCategory, toggleActiveCategory }, children: jsxRuntime.jsxs(HandleEmojiClickContext.Provider, { value: { handleEmojiSelect }, children: [jsxRuntime.jsx(NavigationSection, {}), jsxRuntime.jsx(EmojiSection, {})] }) }) }));
};

exports.Picker = Picker;
